NAME = "blue_geo"

ICON = "🌐"

DESCRIPTION = f"{ICON} AI for precise geospatial data analysis and visualization."

VERSION = "4.21.1"

REPO_NAME = "blue-geo"

MARQUEE = (
    "https://github.com/kamangir/assets/raw/main/nbs/ukraine-timemap/QGIS.png?raw=true"
)



from blue_geo import NAME, VERSION, DESCRIPTION, ICON
from blue_geo.logger import logger
from blueness.argparse.generic import main

success, message = main(__file__, NAME, VERSION, DESCRIPTION, ICON)
if not success:
    logger.error(message)


